datatables-colvis
=================

Shim repository for http://github.com/DataTables/ColVis

Package Managers
----------------

* [npm](http://npmjs.org/package/drmonty-datatables-colvis): `drmonty-datatables-colvis`
* [Bower](http://twitter.github.com/bower/): `drmonty-datatables-colvis`
* [Composer](http://packagist.org/packages/drmonty/datatables-colvis): `drmonty/datatables-colvis`
* [Component](http://component.io): `drmonty/datatables-colvis`